function varargout = blade_worth_gui(varargin)
% BLADE_WORTH_GUI M-file for blade_worth_gui.fig

% Updates:
%   minor edits to default to the Regrod data for Jan 2011 on startup and to only
%     present files of the form B*.dat  (JRWhite, Jan 2012)

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @blade_worth_gui_OpeningFcn, ...
                   'gui_OutputFcn',  @blade_worth_gui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

function Closing_Function(hObject, eventdata, handles)
close(findobj('Tag','blade_worth_plot'));
closereq;

% --- Executes just before blade_worth_gui is made visible.
function blade_worth_gui_OpeningFcn(hObject, eventdata, handles, varargin)
handles.output = hObject;
guidata(hObject, handles);


global fig dt bp ep
dt = zeros(15,1);
ep = zeros(15,1);
bp = zeros(15,1);

% Display UML Logo
[imgdata,imgmap] = imread('uml.gif','gif');
img = image(imgdata, 'Parent', handles.uml_logo);
set(handles.blade_worth_main, 'Colormap', imgmap);
set(handles.uml_logo, ...
    'Visible', 'off', ...
    'YDir'   , 'reverse'       , ...
    'XLim'   , get(img,'XData'), ...
    'YLim'   , get(img,'YData')  ...
    );
% Get listing of directory contents and list all *.dat files in the file
% selection pop-up box.
a = dir('B*.dat');
files = cell(length(a)+1,1);
files(1) = cellstr('Select File...');
for i = 1:length(a)
    files(i+1) = cellstr(a(i).name);
end;
init_plot = strmatch('BRRdata_M25_jan2011',files);
set(findobj('Tag','existing_file_menu'),'Value',init_plot(1));
set(findobj('Tag','existing_file_menu'),'String',files);
blade_worth_plot();
fig = figure(findobj('Tag','blade_worth_plot'));
axes(findobj('Tag','bw_axes'));

% Load file and plot flux.
existing_file_menu_Callback(handles.existing_file_menu, eventdata, handles); 


function varargout = blade_worth_gui_OutputFcn(hObject, eventdata, handles) 
varargout{1} = handles.output;

%% File access functions
% Loads the data from the data file
function load_file(handles,hObject)
global bp ep dt
if ~(get(hObject,'Value') == 1)
    file = get(hObject,'String');
    fid = fopen(file{get(hObject,'Value')});
    q = textscan(fid,'%s',4,'delimiter','\n','commentStyle','%');
    set(handles.date_text,'String',q{1}(1));
    set(handles.coreID_text,'String',q{1}(2));
    set(handles.blade_name_text,'String',q{1}(3));
    set(handles.no_of_points_text,'String',q{1}(4));
    q2 = textscan(fid,'%f %f %f');
    bp = q2{1};
    ep = q2{2};
    dt = q2{3};


    if str2double(get(handles.no_of_points_text,'String')) > 15,...
            set(handles.no_of_points_text,'String','15'); end;

    for i = 1:str2double(get(handles.no_of_points_text,'String'))
        boxnum = num2str(i);
        bpbox = ['bp' boxnum];
        epbox = ['ep' boxnum];
        dtbox = ['dt' boxnum];
        set(findobj('Tag',bpbox),'String',bp(i))
        set(findobj('Tag',epbox),'String',ep(i))
        set(findobj('Tag',dtbox),'String',dt(i))
    end;
    fclose(fid);
end;

function create_file(handles)
global bp ep dt
date = get(handles.date_text,'String');
coreid = get(handles.coreID_text,'String');
blade = get(handles.blade_name_text,'String');
no = get(handles.no_of_points_text,'String');
[fname,path] = uiputfile({'*.dat','DAT Files';'*.*','All Files'},'Save Data File','BladeID.dat');
if ~(isequal(fname,0)||isequal(path,0))
    fid = fopen([path fname],'w');
    fprintf(fid,'%s \n',char(date));
    fprintf(fid,'%s \n',char(coreid));
    fprintf(fid,'%s \n',char(blade));
    fprintf(fid,'%s \n',char(no));
    for i = 1:str2double(char(no))
        fprintf(fid,'    %3.3f   %3.3f   %3.3f \n',bp(i),ep(i),dt(i));
    end;
    fclose(fid);
    
end;
%% Gain data for new data file
function refresh_data(handles)
global dt bp ep
bp = zeros(str2double(get(handles.no_of_points_text,'String')),1);
ep = zeros(str2double(get(handles.no_of_points_text,'String')),1);
dt = zeros(str2double(get(handles.no_of_points_text,'String')),1);
for i = 1:str2double(get(handles.no_of_points_text,'String'))
     boxnum = num2str(i);
     bpbox = ['bp' boxnum];
     epbox = ['ep' boxnum];
     dtbox = ['dt' boxnum];
     bp(i) = str2double(get(findobj('Tag',bpbox),'String'));
     ep(i) = str2double(get(findobj('Tag',epbox),'String'));
     dt(i) = str2double(get(findobj('Tag',dtbox),'String'));
end;

%% Calcuation of Blade Worth
%   This Mfile reads blade worth data from a file and creates differential
%   and integral worth curves.  The format of the data file is as follows:
%       % Case Title
%       Measurement Date
%       Core ID
%       Blade ID
%       Number of Expt Points
%       z1   z2   DT    
%   The above line is repeated for each data point and it contains the following 
%   data:  initial blade height (in)    final blade height (in)   doubling time (sec)
%
%   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION
%
%     There needs to be at least six experimental data points for Model C.
%     The experimental data should be roughly evenly spaced over the 26 in 
%     span for the blade traverse in the UMLRR.  Also, you should expect
%     a coefficient of determination of at least 0.90 - 0.95 for a REASONABLE 
%     fit.  Anything less than 0.90 should be treated with real caution -- this 
%     is a pretty bad fit!!! 
%
%   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION   CAUTION
%
%   The differential worth data are fit to a theoretical model and 
%   to a combined cubic polynomial and cosine function, as follows:
%
%     A. theoretical model      y(x) = a1*(1 - cos(2*pi*x/H)
%
%     C. combined poly+sinusoid y(x) = c1 + c2*x + c3*x^2 + c4*x^3 + c5*cos(2*pi*x/H)
%
%   where x -> distance from bottom of core (distance withdrawn) (inches)
%         y -> differential blade worth  (% DK/K per inch)
%         H -> full range of the blade traverse (26 inches in the UMLRR)
%
%   File written by JRWhite, Umass-Lowell (July 30, 1999)
%   Modified by Justin Byard on August 1, 2000.
%   Modified by JRWhite to add the theoretical model back into the 
%     calculation.   (Jan. 29, 2001)
%   JRWhite made lots of changes: (Jan. 4-5, 2002)
%    -> Modified calculation of zmid (this was a problem for some cases)
%    -> Added additional output edit
%    -> Also changed lower limit of "Bad Data" message
%    -> Added two zero reactivity points at the ends instead of just one point
%    -> Added calc of excess reactivity given input blade height
%    -> Changed input to include doubling time (DT) in seconds directly and then
%       to compute the reactivity internally using the six delayed neutron group
%       approximation.  Note that this modification is a major change that 
%       requires a different input file!!! Thus, all old files that use this new 
%       code will have to be updated!!!      *** THIS IS A BIGGIE ***
%   Simply changed the name of this version of the code (the DT version) to reflect
%     that the code requires doubling time input in seconds.  This was done to
%     distinguish it from the DK version, which requires Dk/K  per inch data as   
%     input. No other changes were made here.  (Oct 20, 2002)
%   Modified by JRWhite to remove analysis of simple theoretical model (Aug 18, 2005)
%    -> I have ample evidence that the combined poly + sinusoid is much better than
%       the simple theoretical model from Lamarsh.  Thus, it does not really add 
%       anything to continue to carry along this extra bagage (this is now consistent
%       with the Dk version)...

function plot_worth()
global dt bp ep fig
m_date = get(findobj('Tag','date_text'),'String');
c_ID = get(findobj('Tag','coreID_text'),'String');
b_ID = get(findobj('Tag','blade_name_text'),'String');
ndpt = str2double(get(findobj('Tag','no_of_points_text'),'String'));
DT = dt;
z1 = bp;
z2 = ep;
ready = 1;
if (dt(1)==0)||((ep(1)==0)&&(bp(1)==0)), ready = 0; end;
if ready > 0
q = 1;
for i = 1:ndpt
    q = q+1;
    if (dt(i)==0)||((ep(i)==0)&&(bp(i)==0)), q = q-2; break; end;
end;
if q > ndpt, q=q-1; end;
ndpt = q;
%   Compute the reactivity in terms of the doubling time using the six delayed 
%   neutron group approximation
      Beta = [0.00026 0.00146 0.00129 0.00279 0.00088 0.00018];% delayed neutron frac
      dc = [0.013 0.032 0.116 0.311 1.400 3.870];              % decay const. (1/sec)
      GT = 6.45e-5;  Beff = 0.0078;  % generation time (sec) and beta eff (LEU FSAR)
      Ibar = Beff/sum(Beta);             
      BetaEff = Ibar*Beta;
%
      Per = DT(1:ndpt)/log(2);
      dkk = zeros(ndpt,1); % reactor period (sec) & space for %DK/K
      for n = 1:ndpt
        dkk(n) = GT/Per(n) + sum(BetaEff./(1 + dc*Per(n)));
      end
      dkk = dkk*100;
      
%   Now put these data into useful form and add on two zero-worth points at the ends 
      H = 26;               % maximum blade traverse (inches)
      dz = z2(1:ndpt)-z1(1:ndpt);           % delta z by point
      zmid = (z1(1:ndpt)+z2(1:ndpt))/2;     % midpoint location
      dkkpi = dkk./dz;      % Dk/k per inch
      z1 = [0; 0; z1(1:ndpt); H; H];   z2 = [0; 0; z2(1:ndpt); H; H];     DT = [0; 0; DT(1:ndpt); 0; 0];
      x = [0; 0; zmid; H; H];   y = [0; 0; dkkpi; 0; 0];   N = length(x);
%
%   Now sort the data in ascending order for presentation and plotting (just in case)
      [xp,ix] = sort(x);  yp = y(ix);
      z1p = z1(ix);   z2p = z2(ix);   DTp = DT(ix);
%
%   Edit raw data and the computed data for the diff worth curve fits 
%       fprintf(1,'\n\n  Summary Data for %s   Core ID: %s   (%s) \n', ...
%                b_ID,c_ID,m_date)
%       fprintf(1,'\n  Raw Expt + Computed Data for %s \n',b_ID);
%       fprintf(1,'    Initial Ht.     Final Ht.    Doubling Time       Midpoint    Diff. Worth  \n');
%       fprintf(1,'       (in)           (in)           (sec)             (in)     (Dk/k per in) \n');
%       for n = 1:N
%         fprintf(1,'   %8.2f       %8.2f       %8.1f          %8.2f      %8.4f \n', ...
%                  z1p(n),z2p(n),DTp(n),xp(n),yp(n));
%       end
%
%   Combined Polynomial + Sinusoid
%
%   generate and solve normal equations  (Pc=q)
      s1 = sum(xp);  s2 = sum(xp.*xp);    s3 = sum(xp.^3);  s4 = sum(xp.^4);
      s5 = sum(xp.^5);                    s6 = sum(xp.^6);
      s7 = sum(cos(2*pi*xp/H));           s8 = sum(xp.*cos(2*pi*xp/H));
      s9 = sum(xp.*xp.*cos(2*pi*xp/H));  s10 = sum(xp.^3.*cos(2*pi*xp/H));
      s11 = sum(cos(2*pi*xp/H).^2);
      P = [ N  s1  s2  s3  s7;
            s1  s2  s3  s4  s8;
            s2  s3  s4  s5  s9;
            s3  s4  s5  s6 s10;
            s7  s8  s9 s10 s11];
      q = [sum(yp) sum(yp.*xp) sum(yp.*xp.*xp) sum(yp.*xp.^3) sum(yp.*cos(2*pi*xp/H))]';
      c = P\q;
      for i = 1:5
          tagname = ['c' num2str(i) '_text'];
          set(findobj('Tag',tagname),'String',['c' num2str(i) ' = ' num2str(c(i),'%12.4e')]);
      end;
%       fprintf(1,'\n\n  Coeffs for Combined Poly-Sinusoid Model:\n    %12.4e %12.4e %12.4e %12.4e %12.4e \n',c);
%      
%   do error analysis
      ym = sum(y)/N;             % mean value of y
      St = sum((y-ym).^2);       % sum of squares of deviation (original data)
      f3 =  polyval(c(4:-1:1),xp) + c(5)*cos(2*pi*xp/H);  % Model C at expt pts
      Sr3 = sum((f3-yp).^2);     % sum of squares of residuals (model - org data)
%     Syx3 = sqrt(Sr3/(N-5));    % standard dev. of regression model 
      r3 = (St - Sr3)/St;        % coeff of determination (about unity for good fit)
      
      set(findobj('Tag','rsquared_text'),'String',['r^2 = ' num2str(r3,'%1.4f')]);
%      
%  plot data for differential worth (both models and the expt. data)
      NN = 100;    xx = linspace(xp(1),H,NN);
      y3 = polyval(c(4:-1:1),xx) + c(5)*cos(2*pi*xx/H);
      cci = [c(4)/4 c(3)/3 c(2)/2 c(1) 0];
      yy3 = polyval(cci,xx) + c(5)*(H/(2*pi))*sin(2*pi*xx/H);
      
      total_worth = c(1)*H + c(2)*H^2/2 + c(3)*H^3/3 + c(4)*H^4/4 + c(5)*H/(2*pi)*sin(2*pi);
      set(findobj('Tag','total_worth'),'String',num2str(total_worth,'%1.3f'));
      blade_worth_plot('calc_reactivity_change');
      axes(findobj('Tag','bw_axes'));
   if get(findobj('Tag','differential_worth_rb'),'Value') == 1
%   plot data for differential worth (both models and the expt. data)
      figure(fig);
      handl = plot(xx,y3,'r-',xp,yp,'bo','LineWidth',2);grid on;
      set(gca,'XTick',0:2:H);
  %    axis auto; 
      v = axis; v(1) = 0; v(2) = H; axis(v);
      title(['Differential Worth for ',char(b_ID), ...
            '  Core ID: ',char(c_ID),'  (',char(m_date),')'])
      xlabel('Distance Withdrawn (inches)');
      ylabel('Differential Worth (%DK/K per inch)')
      legend(handl,'Sine+Poly Model','Expt Points','Location','NorthEast')
   else
%   calc and plot data for integral worth  
      figure(fig);
      handl = plot(xx,yy3,'r-','LineWidth',2);grid on;
      set(gca,'XTick',0:2:H);
   %   axis auto;
      v = axis; v(1) = 0; v(2) = H; v(3) = 0; axis(v);
      title(['Integral Worth for ',char(b_ID), ...
            '  Core ID: ',char(c_ID),'  (',char(m_date),')'])
      xlabel('Distance Withdrawn (inches)')
      ylabel('Integral Worth (%DK/K)','Interpreter','none');
   end;
   hold on;
   blade_worth_plot('draw_reactivity_change');
   hold off;
   set(gca,'Tag','bw_axes')
   
% %   edit quantitative statistical info
%       fprintf(1,'\n\n  Summary data from the error analysis:\n')
%       fprintf(1,'    sum of squares of errors:   %10.3e   \n',Sr3);
%       fprintf(1,'    standard error of estimate: %10.3e   \n',Syx3);
%       fprintf(1,'    coeff of determination:     %10.3e   \n',r3);
%       fprintf(1,'\n    total worth (%%Dk/k):      %10.3f  \n',yy3(NN));
%       fprintf(1,'\n')
% %
% %   determine excess reactivity associated with this blade
%       bht = input('  Input blade height (inches withdrawn) for excess reactivity calc: ');
%       er3 = yy3(NN) - (polyval(cci,bht) + c(5)*(H/(2*pi))*sin(2*pi*bht/H));
%       fprintf(1,'    excess worth (%%Dk/k):    %10.3f   \n', er3)
% %
% %   print warning (if needed)
      if r3 < 0.90,
        set(findobj('Tag','rsquared_text'),'ForegroundColor',[1 0 0]);
      elseif r3 < 0.95,
        set(findobj('Tag','rsquared_text'),'ForegroundColor',[1 0.5 0]);
      else
        set(findobj('Tag','rsquared_text'),'ForegroundColor',[0 .7 0]);
      end
      figure(findobj('Tag','blade_worth_main'));
end;


%% Callbacks
function new_data_rb_Callback(hObject, eventdata, handles)
set(hObject,'Value',1);
set(findobj('Tag','existing_data_rb'),'Value',0);
set(findobj('Tag','existing_file_menu'),'Enable','off');
set(findobj('Tag','save_button'),'Enable','on');
for i = 1:str2double(get(handles.no_of_points_text,'String'))
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','on');
    set(findobj('Tag',epbox),'Enable','on');
    set(findobj('Tag',dtbox),'Enable','on');
end;
for i = (str2double(get(handles.no_of_points_text,'String'))+1):15
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','off');
    set(findobj('Tag',bpbox),'String','0');
    set(findobj('Tag',epbox),'Enable','off');
    set(findobj('Tag',epbox),'String','0');
    set(findobj('Tag',dtbox),'Enable','off');
    set(findobj('Tag',dtbox),'String','0');
end;
set(handles.date_text,'Enable','on');
set(handles.coreID_text,'Enable','on');
set(handles.blade_name_text,'Enable','on');
set(handles.no_of_points_text,'Enable','on');
refresh_data(handles)
plot_worth()

function existing_data_rb_Callback(hObject, eventdata, handles)
set(hObject,'Value',1);
set(findobj('Tag','new_data_rb'),'Value',0);
a = dir('*.dat');
files = cell(length(a)+1,1);
files(1) = cellstr('Select File...');
for i = 1:length(a)
    files(i+1) = cellstr(a(i).name);
end;
set(findobj('Tag','existing_file_menu'),'Value',1);
set(findobj('Tag','existing_file_menu'),'String',files);
set(findobj('Tag','existing_file_menu'),'Enable','on');
set(findobj('Tag','save_button'),'Enable','off');
load_file(handles,handles.existing_file_menu);
for i = 1:str2double(get(handles.no_of_points_text,'String'))
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','inactive');
    set(findobj('Tag',epbox),'Enable','inactive');
    set(findobj('Tag',dtbox),'Enable','inactive');
end;
for i = (str2double(get(handles.no_of_points_text,'String'))+1):15
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','off');
    set(findobj('Tag',bpbox),'String','0');
    set(findobj('Tag',epbox),'Enable','off');
    set(findobj('Tag',epbox),'String','0');
    set(findobj('Tag',dtbox),'Enable','off');
    set(findobj('Tag',dtbox),'String','0');
end;
set(handles.date_text,'Enable','inactive');
set(handles.coreID_text,'Enable','inactive');
set(handles.blade_name_text,'Enable','inactive');
set(handles.no_of_points_text,'Enable','inactive');


function existing_file_menu_Callback(hObject, eventdata, handles)
load_file(handles,hObject);
for i = 1:str2double(get(handles.no_of_points_text,'String'))
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','inactive');
    set(findobj('Tag',epbox),'Enable','inactive');
    set(findobj('Tag',dtbox),'Enable','inactive');
end;
for i = (str2double(get(handles.no_of_points_text,'String'))+1):15
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','off');
    set(findobj('Tag',bpbox),'String','0');
    set(findobj('Tag',epbox),'Enable','off');
    set(findobj('Tag',epbox),'String','0');
    set(findobj('Tag',dtbox),'Enable','off');
    set(findobj('Tag',dtbox),'String','0');
end;    
plot_worth()



function date_text_Callback(hObject, eventdata, handles)
plot_worth()


function coreID_text_Callback(hObject, eventdata, handles)
plot_worth()


function blade_name_text_Callback(hObject, eventdata, handles)
plot_worth()


function no_of_points_text_Callback(hObject, eventdata, handles)
if str2double(get(hObject,'String')) > 15, set(hObject,'String','15'); end;
if str2double(get(hObject,'String')) < 5, set(hObject,'String','5'); end;
for i = 1:str2double(get(hObject,'String'))
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','on');
    set(findobj('Tag',epbox),'Enable','on');
    set(findobj('Tag',dtbox),'Enable','on');
end;
for i = (str2double(get(hObject,'String'))+1):15
    boxnum = num2str(i);
    bpbox = ['bp' boxnum];
    epbox = ['ep' boxnum];
    dtbox = ['dt' boxnum];
    set(findobj('Tag',bpbox),'Enable','off');
    set(findobj('Tag',bpbox),'String','0');
    set(findobj('Tag',epbox),'Enable','off');
    set(findobj('Tag',epbox),'String','0');
    set(findobj('Tag',dtbox),'Enable','off');
    set(findobj('Tag',dtbox),'String','0');
end;
refresh_data(handles)
plot_worth()

function save_button_Callback(hObject, eventdata, handles)
create_file(handles)

function theory_menu_item_Callback(hObject, eventdata, handles)
open blade_worth_theory.pdf;


function print_menu_item_Callback(hObject, eventdata, handles)
printdlg(handles.blade_worth_main);


function exit_menu_item_Callback(hObject, eventdata, handles)
global fig
close(fig);
close(handles.blade_worth_main);



%% Beginning Position boxes
function bp1_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp2_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp3_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp4_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp5_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp6_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp7_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp8_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp9_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp10_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp11_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp12_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp13_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp14_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function bp15_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()

%% End Position boxes
function ep1_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep2_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep3_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep4_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep5_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep6_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep7_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep8_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep9_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep10_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep11_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep12_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep13_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep14_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function ep15_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()

%% Doubling Time boxes
function dt1_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt2_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt3_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt4_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt5_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt6_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt7_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt8_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt9_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt10_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt11_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt12_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt13_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt14_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()
function dt15_Callback(hObject, eventdata, handles)
refresh_data(handles)
plot_worth()

%% Junky stuff
function dt1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt2_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt3_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt4_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt5_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt6_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt7_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt8_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt9_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt10_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt11_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt12_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt14_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt13_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function dt15_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function existing_file_menu_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function date_text_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function coreID_text_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function blade_name_text_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function no_of_points_text_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp2_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp3_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp4_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp5_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp6_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp7_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp8_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp9_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp10_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp11_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp12_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp13_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp14_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function bp15_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep2_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep3_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep4_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep5_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep6_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep7_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep8_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep9_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep10_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep11_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep12_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep13_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep14_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function ep15_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end